@@ -92,7 +92,7 @@ def upgrade_style(style, source, dest=None):
         >>> import os
         >>> rna.plotting.use('matplotlib')
         >>> rna.plotting._backend_mod.upgrade_style(
-        ...     'tfields',
+        ...     'rna',
         ...     os.path.join(os.path.dirname(rna.plotting.__file__),
         ...                  'mplstyles/rna.mplstyle'))
 
@@ -382,15 +382,17 @@ def plot_mesh(vertices, faces, **kwargs):
         from rna.plotting.colors import color_fmt
         orig_fmt = color_fmt(color)
         orig_color = color
-        color = po.format_colors(color,
-                                 fmt='rgba',
-                                 length=len(faces))
+
         nanMask = np.isnan(color)
         if nanMask.any():
             warnings.warn("nan found in colors. Removing corresponding faces!")
             color = color[~nanMask]
             faces = faces[~nanMask]
 
+        color = po.format_colors(color,
+                                 fmt='rgba',
+                                 length=len(faces))
+
         edgecolor = po.pop('edgecolor', None)
         alpha = po.pop('alpha', None)
         # delete norm arguments
@@ -404,9 +406,9 @@ def plot_mesh(vertices, faces, **kwargs):
 
         if edgecolor is not None:
             artist.set_edgecolor(edgecolor)
-            artist.set_facecolors(color)
+            artist.set_facecolors(color.tolist())
         else:
-            artist.set_color(color)
+            artist.set_color(color.tolist())
         if orig_fmt == 'norm':
             # sets vmin, vmax to min, max of val
             artist.set_array(np.array(orig_color))
@@ -773,14 +775,14 @@ def set_legend(axes, artists, **kwargs):
     if table and labels is None and ncol is None:
         table_title = kwargs.pop('table_title', '')
         labels = np.array([h.get_label() for h in handles])
-        labels = [l.split(',') for l in labels]
+        labels = [label.split(',') for label in labels]
         captions_i = []
         captions_j = []
-        for l in labels:
-            if l[0] not in captions_i:
-                captions_i.append(l[0])
-            if l[1] not in captions_j:
-                captions_j.append(l[1])
+        for label in labels:
+            if label[0] not in captions_i:
+                captions_i.append(label[0])
+            if label[1] not in captions_j:
+                captions_j.append(label[1])
 
         shape = (len(captions_i),
                  len(captions_j))
